/**
 * This work was created by participants in the DataONE project, and is
 * jointly copyrighted by participating institutions in DataONE. For
 * more information on DataONE, see our web site at http://dataone.org.
 *
 *   Copyright 2014
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dataone.tidy.dao;

import java.text.ParseException;
import java.util.List;
import java.util.Map;

import javax.sql.DataSource;

import junit.framework.Assert;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.dataone.cn.dao.exceptions.DataAccessException;
import org.dataone.service.types.v1.Identifier;
import org.dataone.service.types.v1.NodeReference;
import org.dataone.service.types.v1.SystemMetadata;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.springframework.jdbc.core.JdbcTemplate;

public class SystemMetadataTidyDaoImplTest {

    private static final Log log = LogFactory.getLog(SystemMetadataTidyDaoImplTest.class);

    private DataSource dataSource = new H2RepositoryConfiguration().dataSource();
    private SystemMetadataTidyDaoImpl tidyDao = new SystemMetadataTidyDaoImpl(dataSource);

    private JdbcTemplate jdbc = new JdbcTemplate(dataSource);
    private SystemMetadataTidyDaoImplUtil sysMetaTestUtil = new SystemMetadataTidyDaoImplUtil();

    @Before
    public void createTables() {
        sysMetaTestUtil.createTables(jdbc);
    }

    @After
    public void dropTables() {
        sysMetaTestUtil.dropTables(jdbc);
    }

    @Test
    public void testListIdentifiersCount() throws DataAccessException {
        sysMetaTestUtil.populateAllMergeSourceTablesWithTestA(jdbc);
        List<Identifier> ids = tidyDao.listIdentifiers();
        Assert.assertEquals(1, ids.size());
    }

    @Test
    public void testGetSystemMetadata() throws DataAccessException, ParseException {
        sysMetaTestUtil.populateAllMergeSourceTablesWithTestA(jdbc);

        Identifier id = new Identifier();
        id.setValue("6f632bd1cc2772bdcc43bafdbb9d8669.1.1");
        Map<NodeReference, SystemMetadata> smdMap = tidyDao.getSystemMetadata(id);
        Assert.assertEquals(3, smdMap.keySet().size());

        sysMetaTestUtil.verifyAllSourceTestA(smdMap);
    }
}
